package com.phm.manage.mapper;

import com.phm.manage.domain.AnalyzeResult;

import java.util.List;

/**
 * 数据解析结果Mapper接口
 *
 * @author phm
 * @date 2023-08-22
 */
public interface AnalyzeResultMapper {
    /**
     * 查询数据解析结果
     *
     * @param id 数据解析结果主键
     * @return 数据解析结果
     */
    public AnalyzeResult selectAnalyzeResultById(Long id);

    /**
     * 查询数据解析结果列表
     *
     * @param analyzeResult 数据解析结果
     * @return 数据解析结果集合
     */
    public List<AnalyzeResult> selectAnalyzeResultList(AnalyzeResult analyzeResult);

    /**
     * 新增数据解析结果
     *
     * @param analyzeResult 数据解析结果
     * @return 结果
     */
    public int insertAnalyzeResult(AnalyzeResult analyzeResult);

    /**
     * 修改数据解析结果
     *
     * @param analyzeResult 数据解析结果
     * @return 结果
     */
    public int updateAnalyzeResult(AnalyzeResult analyzeResult);

    /**
     * 删除数据解析结果
     *
     * @param id 数据解析结果主键
     * @return 结果
     */
    public int deleteAnalyzeResultById(Long id);

    /**
     * 批量删除数据解析结果
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteAnalyzeResultByIds(Long[] ids);
}
